powered by
Extracts central estimates from stan_fit object for specified parameter
extract_central_estimates( seromodel, serosurvey, alpha = 0.05, par_name = "foi_vector" )
A dataframe with the following columns
median
Median of the samples computed as the 0.5 quantile
lower
Lower quantile alpha
alpha
upper
Upper quantile 1 - alpha
1 - alpha
stan_fit object obtained from sampling a model with fit_seromodel
survey_year
Year in which the survey took place (only needed to plot time models)
age_min
Floor value of the average between age_min and age_max
age_max
The size of the sample
n_sample
Number of samples for each age group
n_seropositive
Number of positive samples for each age group
1 - alpha indicates the credibility level to be used
String specifying the parameter to be extracted from seromodel
seromodel
data(veev2012) seromodel <- fit_seromodel(veev2012, iter = 100) central_estimates <- extract_central_estimates( seromodel, veev2012, par_name = "foi" )
Run the code above in your browser using DataLab