sf_uniform: Sets uniform distribution parameters for sampling
Description
Sets uniform distribution parameters for sampling
Usage
sf_uniform(min = 0, max = 10)
Value
List with specified statistics and name of the model
Arguments
- min
Minimum value of the random variable of the uniform distribution
- max
Maximum value of the random variable of the uniform distribution